@@ -231,11 +231,6 @@ class ExternalData(UserScopedModel):
              self.source_updated_at > self.processed_at)
         )
 
-    @property
-    def chunks_count(self) -> int:
-        """Get the number of chunks for this external data."""
-        return self.chunks.count()
-
     def get_config_value(self, key: str, default=None):
         """Get a configuration value."""
         return self.source_config.get(key, default)
