@@ -53,14 +53,10 @@ class SecurityConfig(BaseConfig):
     session_cookie_secure: bool = Field(default=False, description="Secure session cookies")
     session_cookie_age: int = Field(default=86400, description="Session cookie age in seconds")
 
-    # Production domains for auto-configuration
+    # Production domains for auto-configuration (deprecated - use DjangoConfig.security_domains instead)
     production_domains: List[str] = Field(
-        default_factory=lambda: [
-            "https://carapis.com",
-            "https://api2.carapis.com",
-            "https://djangocfg.com",
-        ],
-        description="Production domains for security configuration"
+        default_factory=list,
+        description="DEPRECATED: Use DjangoConfig.security_domains instead. Will be removed in future versions."
     )
 
     @field_validator('hsts_max_age')
@@ -71,12 +67,19 @@ class SecurityConfig(BaseConfig):
             raise ValueError("HSTS max age must be non-negative")
         return v
 
-    def configure_for_production(self) -> None:
-        """Configure security settings for production."""
+    def configure_for_production(self, domains: List[str] = None) -> None:
+        """
+        Configure security settings for production.
+
+        Args:
+            domains: Optional list of production domains. If not provided, uses production_domains field.
+        """
+        prod_domains = domains or self.production_domains
+
         self.cors_allow_all_origins = False
-        self.cors_allowed_origins = self.production_domains
+        self.cors_allowed_origins = prod_domains
         self.csrf_cookie_secure = True
-        self.csrf_trusted_origins = self.production_domains
+        self.csrf_trusted_origins = prod_domains
         self.ssl_redirect = True
         self.hsts_enabled = True
         self.session_cookie_secure = True
@@ -99,14 +102,17 @@ class SecurityConfig(BaseConfig):
 
         # function smart diapason for dev ports
         def smart_diapason(start: int, end: int) -> List[str]:
-            return [f'http://localhost:{i}' for i in range(start, end)]
+            """Generate localhost origins for port range."""
+            origins = []
+            for i in range(start, end):
+                origins.append(f'http://localhost:{i}')
+                origins.append(f'http://127.0.0.1:{i}')
+            return origins
 
-        dev_local_origins = [
-            'http://localhost:3000',
-            'http://localhost:8000',
-            'http://127.0.0.1:3000',
-            'http://127.0.0.1:8000',
-        ] + smart_diapason(3000, 3010) + smart_diapason(8000, 8010)
+        # Wide coverage of common dev ports
+        # 3000-5000: Frontend frameworks (React, Vue, Next.js, etc)
+        # 8000-9000: Backend frameworks (Django, Flask, FastAPI, etc)
+        dev_local_origins = smart_diapason(3000, 5000) + smart_diapason(8000, 9000)
 
         # Combine dev defaults with existing trusted origins (from security_domains)
         # Remove duplicates while preserving order
