@@ -19,7 +19,7 @@ from .config import (
 )
 
 # Generators
-from .generator import GoGenerator, PythonGenerator, TypeScriptGenerator
+from .generator import GoGenerator, ProtoGenerator, PythonGenerator, TypeScriptGenerator
 
 # Groups
 from .groups import GroupDetector, GroupManager
@@ -53,4 +53,5 @@ __all__ = [
     "PythonGenerator",
     "TypeScriptGenerator",
     "GoGenerator",
+    "ProtoGenerator",
 ]
