@@ -25,6 +25,7 @@ from typing import Literal
 from ..ir import IRContext
 from .base import GeneratedFile
 from .go import GoGenerator
+from .proto import ProtoGenerator
 from .python import PythonGenerator
 from .typescript import TypeScriptGenerator
 
@@ -32,10 +33,12 @@ __all__ = [
     "PythonGenerator",
     "TypeScriptGenerator",
     "GoGenerator",
+    "ProtoGenerator",
     "GeneratedFile",
     "generate_python",
     "generate_typescript",
     "generate_go",
+    "generate_proto",
     "generate_client",
 ]
 
@@ -122,9 +125,41 @@ def generate_go(context: IRContext, output_dir: Path | None = None, **kwargs) ->
     return files
 
 
+def generate_proto(context: IRContext, output_dir: Path | None = None, **kwargs) -> list[GeneratedFile]:
+    """
+    Generate Protocol Buffer definitions from IR.
+
+    Args:
+        context: IRContext from parser
+        output_dir: Optional output directory (saves files if provided)
+        **kwargs: Additional options (split_files, package_name, etc.)
+
+    Returns:
+        List of GeneratedFile objects
+
+    Examples:
+        >>> files = generate_proto(context)
+        >>> # Or save directly
+        >>> files = generate_proto(context, output_dir=Path("./generated/proto"))
+        >>> # With custom settings
+        >>> files = generate_proto(
+        ...     context,
+        ...     split_files=False,  # Single api.proto file
+        ...     package_name="myapi.v1"
+        ... )
+    """
+    generator = ProtoGenerator(context, **kwargs)
+    files = generator.generate()
+
+    if output_dir:
+        generator.save_files(files, output_dir)
+
+    return files
+
+
 def generate_client(
     context: IRContext,
-    language: Literal["python", "typescript", "go"],
+    language: Literal["python", "typescript", "go", "proto"],
     output_dir: Path | None = None,
     **kwargs,
 ) -> list[GeneratedFile]:
@@ -133,7 +168,7 @@ def generate_client(
 
     Args:
         context: IRContext from parser
-        language: Target language ('python', 'typescript', or 'go')
+        language: Target language ('python', 'typescript', 'go', or 'proto')
         output_dir: Optional output directory
         **kwargs: Additional language-specific options
 
@@ -144,6 +179,7 @@ def generate_client(
         >>> files = generate_client(context, "python")
         >>> files = generate_client(context, "typescript", Path("./generated"))
         >>> files = generate_client(context, "go", Path("./generated"), generate_package_files=True)
+        >>> files = generate_client(context, "proto", Path("./generated"), split_files=False)
     """
     if language == "python":
         return generate_python(context, output_dir)
@@ -151,5 +187,7 @@ def generate_client(
         return generate_typescript(context, output_dir)
     elif language == "go":
         return generate_go(context, output_dir, **kwargs)
+    elif language == "proto":
+        return generate_proto(context, output_dir, **kwargs)
     else:
         raise ValueError(f"Unsupported language: {language}")
