@@ -4,11 +4,18 @@ Django Logging Modules for django_cfg.
 Auto-configuring logging utilities.
 """
 
-from .django_logger import DjangoLogger, get_logger
+from .django_logger import (
+    RESERVED_LOG_ATTRS,
+    DjangoLogger,
+    get_logger,
+    sanitize_extra,
+)
 from .logger import logger
 
 __all__ = [
     "logger",
     "DjangoLogger",
     "get_logger",
+    "sanitize_extra",
+    "RESERVED_LOG_ATTRS",
 ]
