@@ -6,11 +6,53 @@ KISS principle: simple, unified logging configuration.
 
 import logging
 from pathlib import Path
-from typing import Dict
+from typing import Any, Dict, Optional
 
 from ..base import BaseCfgModule
 
 
+# Reserved LogRecord attributes that cannot be used in 'extra'
+# Source: https://docs.python.org/3/library/logging.html#logrecord-attributes
+RESERVED_LOG_ATTRS = {
+    'name', 'msg', 'args', 'created', 'filename', 'funcName', 'levelname',
+    'levelno', 'lineno', 'module', 'msecs', 'message', 'pathname', 'process',
+    'processName', 'relativeCreated', 'thread', 'threadName', 'exc_info',
+    'exc_text', 'stack_info', 'asctime', 'taskName'
+}
+
+
+def sanitize_extra(extra: Optional[Dict[str, Any]]) -> Dict[str, Any]:
+    """
+    Sanitize extra dict by prefixing reserved LogRecord attributes.
+
+    Python's logging module reserves certain attribute names in LogRecord.
+    Using these names in the 'extra' parameter causes a KeyError.
+    This function automatically prefixes conflicting keys with 'ctx_'.
+
+    Args:
+        extra: Dictionary of extra logging context
+
+    Returns:
+        Sanitized dictionary with no reserved attribute conflicts
+
+    Example:
+        >>> sanitize_extra({'module': 'myapp', 'user_id': 123})
+        {'ctx_module': 'myapp', 'user_id': 123}
+    """
+    if not extra:
+        return {}
+
+    sanitized = {}
+    for key, value in extra.items():
+        if key in RESERVED_LOG_ATTRS:
+            # Prefix reserved attributes with 'ctx_'
+            sanitized[f'ctx_{key}'] = value
+        else:
+            sanitized[key] = value
+
+    return sanitized
+
+
 class DjangoLogger(BaseCfgModule):
     """Simple auto-configuring logger."""
 
@@ -205,4 +247,4 @@ def get_logger(name: str = "django_cfg") -> logging.Logger:
 
 
 # Export public API
-__all__ = ['DjangoLogger', 'get_logger']
+__all__ = ['DjangoLogger', 'get_logger', 'sanitize_extra', 'RESERVED_LOG_ATTRS']
